@@ -9,9 +9,7 @@ const stripAnsi = require("strip-ansi");
  * @param {string} str String to quote
  * @returns {string} Escaped string
  */
-const quoteMeta = str => {
-	return str.replace(/[-[\]\\/{}()*+?.^$|]/g, "\\$&");
-};
+const quoteMeta = str => str.replace(/[-[\]\\/{}()*+?.^$|]/g, "\\$&");
 
 const cwd = process.cwd();
 const cwdRegExp = new RegExp(
@@ -101,7 +99,7 @@ describe("snapshots", () => {
 		    "lazyCompilation": undefined,
 		    "outputModule": false,
 		    "syncWebAssembly": false,
-		    "topLevelAwait": false,
+		    "topLevelAwait": true,
 		  },
 		  "externals": undefined,
 		  "externalsPresets": Object {
@@ -117,6 +115,22 @@ describe("snapshots", () => {
 		  "ignoreWarnings": undefined,
 		  "infrastructureLogging": Object {},
 		  "loader": Object {
+		    "environment": Object {
+		      "arrowFunction": true,
+		      "asyncFunction": true,
+		      "bigIntLiteral": true,
+		      "const": true,
+		      "destructuring": true,
+		      "document": true,
+		      "dynamicImport": undefined,
+		      "dynamicImportInWorker": undefined,
+		      "forOf": true,
+		      "globalThis": undefined,
+		      "module": undefined,
+		      "nodePrefixForCoreModules": true,
+		      "optionalChaining": true,
+		      "templateLiteral": true,
+		    },
 		    "target": "web",
 		  },
 		  "mode": "none",
@@ -204,6 +218,12 @@ describe("snapshots", () => {
 		        },
 		        "type": "json",
 		      },
+		      Object {
+		        "type": "json",
+		        "with": Object {
+		          "type": "json",
+		        },
+		      },
 		    ],
 		    "generator": Object {},
 		    "noParse": undefined,
@@ -215,6 +235,7 @@ describe("snapshots", () => {
 		      },
 		      "javascript": Object {
 		        "createRequire": false,
+		        "dynamicImportFetchPriority": false,
 		        "dynamicImportMode": "lazy",
 		        "dynamicImportPrefetch": false,
 		        "dynamicImportPreload": false,
@@ -314,6 +335,7 @@ describe("snapshots", () => {
 		    "crossOriginLoading": false,
 		    "cssChunkFilename": "[name].css",
 		    "cssFilename": "[name].css",
+		    "cssHeadDataCompression": true,
 		    "devtoolFallbackModuleFilenameTemplate": undefined,
 		    "devtoolModuleFilenameTemplate": undefined,
 		    "devtoolNamespace": "webpack",
@@ -327,12 +349,19 @@ describe("snapshots", () => {
 		    ],
 		    "environment": Object {
 		      "arrowFunction": true,
-		      "bigIntLiteral": undefined,
+		      "asyncFunction": true,
+		      "bigIntLiteral": true,
 		      "const": true,
 		      "destructuring": true,
+		      "document": true,
 		      "dynamicImport": undefined,
+		      "dynamicImportInWorker": undefined,
 		      "forOf": true,
+		      "globalThis": undefined,
 		      "module": undefined,
+		      "nodePrefixForCoreModules": true,
+		      "optionalChaining": true,
+		      "templateLiteral": true,
 		    },
 		    "filename": "[name].js",
 		    "globalObject": "self",
@@ -343,6 +372,7 @@ describe("snapshots", () => {
 		    "hotUpdateChunkFilename": "[id].[fullhash].hot-update.js",
 		    "hotUpdateGlobal": "webpackHotUpdatewebpack",
 		    "hotUpdateMainFilename": "[runtime].[fullhash].hot-update.json",
+		    "ignoreBrowserWarnings": undefined,
 		    "iife": true,
 		    "importFunctionName": "import",
 		    "importMetaName": "import.meta",
@@ -354,12 +384,14 @@ describe("snapshots", () => {
 		    "scriptType": false,
 		    "sourceMapFilename": "[file].map[query]",
 		    "sourcePrefix": undefined,
+		    "strictModuleErrorHandling": false,
 		    "strictModuleExceptionHandling": false,
 		    "trustedTypes": undefined,
 		    "uniqueName": "webpack",
 		    "wasmLoading": "fetch",
 		    "webassemblyModuleFilename": "[hash].module.wasm",
 		    "workerChunkLoading": "import-scripts",
+		    "workerPublicPath": "",
 		    "workerWasmLoading": "fetch",
 		  },
 		  "parallelism": 100,
@@ -566,6 +598,9 @@ describe("snapshots", () => {
 		      "exports",
 		    ],
 		    "extensions": Array [],
+		    "importsFields": Array [
+		      "imports",
+		    ],
 		    "mainFields": Array [
 		      "main",
 		    ],
@@ -619,6 +654,7 @@ describe("snapshots", () => {
 		      "hash": true,
 		      "timestamp": true,
 		    },
+		    "unmanagedPaths": Array [],
 		  },
 		  "stats": Object {},
 		  "target": "web",
@@ -647,10 +683,10 @@ describe("snapshots", () => {
 	};
 
 	test("empty config", {}, e =>
-		e.toMatchInlineSnapshot(`Compared values have no visual difference.`)
+		e.toMatchInlineSnapshot("Compared values have no visual difference.")
 	);
 	test("none mode", { mode: "none" }, e =>
-		e.toMatchInlineSnapshot(`Compared values have no visual difference.`)
+		e.toMatchInlineSnapshot("Compared values have no visual difference.")
 	);
 	test("no mode provided", { mode: undefined }, e =>
 		e.toMatchInlineSnapshot(`
@@ -819,6 +855,9 @@ describe("snapshots", () => {
 		-       "minRemainingSize": undefined,
 		+       "minRemainingSize": 0,
 		@@ ... @@
+		-     "cssHeadDataCompression": true,
+		+     "cssHeadDataCompression": false,
+		@@ ... @@
 		-     "pathinfo": false,
 		+     "pathinfo": true,
 		@@ ... @@
@@ -881,13 +920,23 @@ describe("snapshots", () => {
 		+     "outputModule": true,
 		@@ ... @@
 		-   "externalsType": "var",
-		+   "externalsType": "module",
+		+   "externalsType": "module-import",
+		@@ ... @@
+		-       "dynamicImport": undefined,
+		-       "dynamicImportInWorker": undefined,
+		+       "dynamicImport": true,
+		+       "dynamicImportInWorker": true,
+		@@ ... @@
+		-       "module": undefined,
+		+       "module": true,
 		@@ ... @@
 		-     "chunkFilename": "[name].js",
 		+     "chunkFilename": "[name].mjs",
 		@@ ... @@
 		-       "dynamicImport": undefined,
+		-       "dynamicImportInWorker": undefined,
 		+       "dynamicImport": true,
+		+       "dynamicImportInWorker": true,
 		@@ ... @@
 		-       "module": undefined,
 		+       "module": true,
@@ -1050,6 +1099,7 @@ describe("snapshots", () => {
 		@@ ... @@
 		-     "library": undefined,
 		+     "library": Object {
+		+       "amdContainer": undefined,
 		+       "auxiliaryComment": undefined,
 		+       "export": undefined,
 		+       "name": Array [
@@ -1093,6 +1143,7 @@ describe("snapshots", () => {
 			@@ ... @@
 			-     "library": undefined,
 			+     "library": Object {
+			+       "amdContainer": undefined,
 			+       "auxiliaryComment": undefined,
 			+       "export": undefined,
 			+       "name": Array [
@@ -1139,6 +1190,7 @@ describe("snapshots", () => {
 			@@ ... @@
 			-     "library": undefined,
 			+     "library": Object {
+			+       "amdContainer": undefined,
 			+       "auxiliaryComment": undefined,
 			+       "export": undefined,
 			+       "name": Array [
@@ -1188,6 +1240,7 @@ describe("snapshots", () => {
 			@@ ... @@
 			-     "library": undefined,
 			+     "library": Object {
+			+       "amdContainer": undefined,
 			+       "auxiliaryComment": undefined,
 			+       "export": undefined,
 			+       "name": Object {
@@ -1238,6 +1291,7 @@ describe("snapshots", () => {
 			@@ ... @@
 			-     "library": undefined,
 			+     "library": Object {
+			+       "amdContainer": undefined,
 			+       "auxiliaryComment": undefined,
 			+       "export": undefined,
 			+       "name": Object {
@@ -1267,6 +1321,9 @@ describe("snapshots", () => {
 		-     "web": true,
 		+     "web": false,
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		-     "target": "web",
 		+     "target": "node",
 		@@ ... @@
@@ -1293,6 +1350,9 @@ describe("snapshots", () => {
 		-       "fetch",
 		+       "async-node",
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		-     "globalObject": "self",
 		+     "globalObject": "global",
 		@@ ... @@
@@ -1303,8 +1363,9 @@ describe("snapshots", () => {
 		+     "wasmLoading": "async-node",
 		@@ ... @@
 		-     "workerChunkLoading": "import-scripts",
-		-     "workerWasmLoading": "fetch",
 		+     "workerChunkLoading": "require",
+		@@ ... @@
+		-     "workerWasmLoading": "fetch",
 		+     "workerWasmLoading": "async-node",
 		@@ ... @@
 		-         "aliasFields": Array [
@@ -1382,12 +1443,18 @@ describe("snapshots", () => {
 		- Expected
 		+ Received
 
+		@@ ... @@
+		-       "document": true,
+		+       "document": false,
 		@@ ... @@
 		-     "chunkLoading": "jsonp",
 		+     "chunkLoading": "import-scripts",
 		@@ ... @@
 		-       "jsonp",
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		+       "worker",
 		@@ ... @@
 		-   "target": "web",
@@ -1411,6 +1478,9 @@ describe("snapshots", () => {
 		-     "web": true,
 		+     "web": false,
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		-     "target": "web",
 		+     "target": "electron-main",
 		@@ ... @@
@@ -1437,6 +1507,9 @@ describe("snapshots", () => {
 		-       "fetch",
 		+       "async-node",
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		-     "globalObject": "self",
 		+     "globalObject": "global",
 		@@ ... @@
@@ -1447,8 +1520,9 @@ describe("snapshots", () => {
 		+     "wasmLoading": "async-node",
 		@@ ... @@
 		-     "workerChunkLoading": "import-scripts",
-		-     "workerWasmLoading": "fetch",
 		+     "workerChunkLoading": "require",
+		@@ ... @@
+		-     "workerWasmLoading": "fetch",
 		+     "workerWasmLoading": "async-node",
 		@@ ... @@
 		-         "aliasFields": Array [
@@ -1537,6 +1611,9 @@ describe("snapshots", () => {
 		-     "node": false,
 		+     "node": true,
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		-     "target": "web",
 		+     "target": "electron-preload",
 		@@ ... @@
@@ -1563,6 +1640,9 @@ describe("snapshots", () => {
 		-       "fetch",
 		+       "async-node",
 		@@ ... @@
+		-       "document": true,
+		+       "document": false,
+		@@ ... @@
 		-     "globalObject": "self",
 		+     "globalObject": "global",
 		@@ ... @@
@@ -1573,8 +1653,9 @@ describe("snapshots", () => {
 		+     "wasmLoading": "async-node",
 		@@ ... @@
 		-     "workerChunkLoading": "import-scripts",
-		-     "workerWasmLoading": "fetch",
 		+     "workerChunkLoading": "require",
+		@@ ... @@
+		-     "workerWasmLoading": "fetch",
 		+     "workerWasmLoading": "async-node",
 		@@ ... @@
 		-         "aliasFields": Array [
@@ -1664,7 +1745,7 @@ describe("snapshots", () => {
 	`)
 	);
 	test("ecmaVersion", { output: { ecmaVersion: 2020 } }, e =>
-		e.toMatchInlineSnapshot(`Compared values have no visual difference.`)
+		e.toMatchInlineSnapshot("Compared values have no visual difference.")
 	);
 	test("single runtimeChunk", { optimization: { runtimeChunk: "single" } }, e =>
 		e.toMatchInlineSnapshot(`
@@ -1754,6 +1835,7 @@ describe("snapshots", () => {
 		+     "memoryCacheUnaffected": false,
 		+     "name": "default-none",
 		+     "profile": false,
+		+     "readonly": false,
 		+     "store": "pack",
 		+     "type": "filesystem",
 		+     "version": "",
@@ -1798,6 +1880,7 @@ describe("snapshots", () => {
 			+     "memoryCacheUnaffected": false,
 			+     "name": "default-development",
 			+     "profile": false,
+			+     "readonly": false,
 			+     "store": "pack",
 			+     "type": "filesystem",
 			+     "version": "",
@@ -1823,6 +1906,9 @@ describe("snapshots", () => {
 			-       "minRemainingSize": undefined,
 			+       "minRemainingSize": 0,
 			@@ ... @@
+			-     "cssHeadDataCompression": true,
+			+     "cssHeadDataCompression": false,
+			@@ ... @@
 			-     "pathinfo": false,
 			+     "pathinfo": true,
 			@@ ... @@
@@ -1921,6 +2007,7 @@ describe("snapshots", () => {
 			-     "trustedTypes": undefined,
 			-     "uniqueName": "webpack",
 			+     "trustedTypes": Object {
+			+       "onPolicyCreationFailure": "stop",
 			+       "policyName": "@@@Hello_World_",
 			+     },
 			+     "uniqueName": "@@@Hello World!",
@@ -1978,6 +2065,34 @@ describe("snapshots", () => {
 			-   "context": "<cwd>",
 			+   "context": "<cwd>/test/fixtures/browserslist",
 			@@ ... @@
+			-       "arrowFunction": true,
+			-       "asyncFunction": true,
+			-       "bigIntLiteral": true,
+			-       "const": true,
+			-       "destructuring": true,
+			+       "arrowFunction": false,
+			+       "asyncFunction": false,
+			+       "bigIntLiteral": false,
+			+       "const": false,
+			+       "destructuring": false,
+			@@ ... @@
+			-       "dynamicImport": undefined,
+			-       "dynamicImportInWorker": undefined,
+			-       "forOf": true,
+			-       "globalThis": undefined,
+			-       "module": undefined,
+			-       "nodePrefixForCoreModules": true,
+			-       "optionalChaining": true,
+			-       "templateLiteral": true,
+			+       "dynamicImport": false,
+			+       "dynamicImportInWorker": false,
+			+       "forOf": false,
+			+       "globalThis": false,
+			+       "module": false,
+			+       "nodePrefixForCoreModules": false,
+			+       "optionalChaining": false,
+			+       "templateLiteral": false,
+			@@ ... @@
 			-     "chunkLoadingGlobal": "webpackChunkwebpack",
 			+     "chunkLoadingGlobal": "webpackChunkbrowserslist_test",
 			@@ ... @@
@@ -1985,19 +2100,32 @@ describe("snapshots", () => {
 			+     "devtoolNamespace": "browserslist-test",
 			@@ ... @@
 			-       "arrowFunction": true,
-			-       "bigIntLiteral": undefined,
+			-       "asyncFunction": true,
+			-       "bigIntLiteral": true,
 			-       "const": true,
 			-       "destructuring": true,
-			-       "dynamicImport": undefined,
-			-       "forOf": true,
-			-       "module": undefined,
 			+       "arrowFunction": false,
+			+       "asyncFunction": false,
 			+       "bigIntLiteral": false,
 			+       "const": false,
 			+       "destructuring": false,
+			@@ ... @@
+			-       "dynamicImport": undefined,
+			-       "dynamicImportInWorker": undefined,
+			-       "forOf": true,
+			-       "globalThis": undefined,
+			-       "module": undefined,
+			-       "nodePrefixForCoreModules": true,
+			-       "optionalChaining": true,
+			-       "templateLiteral": true,
 			+       "dynamicImport": false,
+			+       "dynamicImportInWorker": false,
 			+       "forOf": false,
+			+       "globalThis": false,
 			+       "module": false,
+			+       "nodePrefixForCoreModules": false,
+			+       "optionalChaining": false,
+			+       "templateLiteral": false,
 			@@ ... @@
 			-     "hotUpdateGlobal": "webpackHotUpdatewebpack",
 			+     "hotUpdateGlobal": "webpackHotUpdatebrowserslist_test",
@@ -2047,6 +2175,7 @@ describe("snapshots", () => {
 			+     "memoryCacheUnaffected": false,
 			+     "name": "default-none",
 			+     "profile": false,
+			+     "readonly": false,
 			+     "store": "pack",
 			+     "type": "filesystem",
 			+     "version": "",
@@ -2130,14 +2259,9 @@ describe("snapshots", () => {
 			-     "css": undefined,
 			-     "futureDefaults": false,
 			+     "cacheUnaffected": true,
-			+     "css": Object {
-			+       "exportsOnly": false,
-			+     },
+			+     "css": true,
 			+     "futureDefaults": true,
 			@@ ... @@
-			-     "topLevelAwait": false,
-			+     "topLevelAwait": true,
-			@@ ... @@
 			+       },
 			+       Object {
 			+         "rules": Array [
@@ -2168,28 +2292,18 @@ describe("snapshots", () => {
 			+         "type": "webassembly/async",
 			+       },
 			+       Object {
-			+         "oneOf": Array [
-			+           Object {
-			+             "resolve": Object {
-			+               "fullySpecified": true,
-			+             },
-			+             "test": /\\.module\\.css$/i,
-			+             "type": "css/module",
-			+           },
-			+           Object {
-			+             "resolve": Object {
-			+               "fullySpecified": true,
-			+               "preferRelative": true,
-			+             },
-			+             "type": "css",
-			+           },
-			+         ],
+			+         "resolve": Object {
+			+           "fullySpecified": true,
+			+           "preferRelative": true,
+			+         },
 			+         "test": /\\.css$/i,
+			+         "type": "css/auto",
 			+       },
 			+       Object {
 			+         "mimetype": "text/css+module",
 			+         "resolve": Object {
 			+           "fullySpecified": true,
+			+           "preferRelative": true,
 			+         },
 			+         "type": "css/module",
 			+       },
@@ -2198,8 +2312,33 @@ describe("snapshots", () => {
 			+         "resolve": Object {
 			+           "fullySpecified": true,
 			+           "preferRelative": true,
-			+         },
+			@@ ... @@
 			+         "type": "css",
+			+       },
+			@@ ... @@
+			-     "generator": Object {},
+			+     "generator": Object {
+			+       "css": Object {
+			+         "esModule": true,
+			+         "exportsOnly": false,
+			+       },
+			+       "css/auto": Object {
+			+         "exportsConvention": "as-is",
+			+         "localIdentName": "[uniqueName]-[id]-[local]",
+			+       },
+			+       "css/global": Object {
+			+         "exportsConvention": "as-is",
+			+         "localIdentName": "[uniqueName]-[id]-[local]",
+			+       },
+			+       "css/module": Object {
+			+         "exportsConvention": "as-is",
+			+         "localIdentName": "[uniqueName]-[id]-[local]",
+			+       },
+			+     },
+			@@ ... @@
+			+       },
+			+       "css": Object {
+			+         "namedExports": true,
 			@@ ... @@
 			+         "exportsPresence": "error",
 			@@ ... @@
@@ -2217,6 +2356,23 @@ describe("snapshots", () => {
 			+     "hashDigestLength": 16,
 			+     "hashFunction": "xxhash64",
 			@@ ... @@
+			+       "css-import": Object {
+			+         "conditionNames": Array [
+			+           "webpack",
+			+           "production",
+			+           "style",
+			+         ],
+			+         "extensions": Array [
+			+           ".css",
+			+         ],
+			+         "mainFields": Array [
+			+           "style",
+			+           "...",
+			+         ],
+			+         "mainFiles": Array [],
+			+         "preferRelative": true,
+			+       },
+			@@ ... @@
 			-       "<cwd>/node_modules/",
 			+       /^(.+?[\\\\/]node_modules[\\\\/])/,
 		`)
@@ -2248,13 +2404,9 @@ describe("snapshots", () => {
 			+     "css": false,
 			+     "futureDefaults": true,
 			@@ ... @@
-			-     "topLevelAwait": false,
-			+     "topLevelAwait": true,
-			@@ ... @@
-			+       },
 			+       Object {
 			+         "rules": Array [
-			+           Object {
+			@@ ... @@
 			+             "descriptionData": Object {
 			+               "type": "module",
 			+             },
@@ -2265,7 +2417,8 @@ describe("snapshots", () => {
 			+         ],
 			+         "test": /\\.wasm$/i,
 			+         "type": "webassembly/async",
-			@@ ... @@
+			+       },
+			+       Object {
 			+         "mimetype": "application/wasm",
 			+         "rules": Array [
 			+           Object {
